Documentation
¶
Overview ¶
Package format provides functions to format shell scripts and file paths.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Hash ¶ added in v0.0.3
Hash deterministically combines each file's contents and its exported variables into a single SHA-256 digest.
func Map ¶
Map takes a map and a format string (like "export %s=%q") and returns a sorted, joined string.
func PosixPath ¶ added in v0.0.9
PosixPath converts a Windows path (like `C:/...`) to Posix format (`/c/...`). Converts regardless of platform if a drive letter is detected.
func WindowsPath ¶ added in v0.0.9
WindowsPath converts a Posix path (like `/c/...`) to Windows format (`C:/...`). Converts regardless of platform if a drive letter is detected.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.