Documentation
¶
Overview ¶
Package variables provides functionality for managing key-value pairs and loading them from files or command-line arguments.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Args ¶
type Args []string
Args represents a list of key=value strings.
func (Args) ToKeyValues ¶
ToKeyValues converts the Args into a Variables map, returning any errors encountered.
type Header ¶
type Header struct {
// Values contains predefined variables to use for templating.
Values Variables `yaml:"values,omitempty"`
// Exclude indicates whether this file should be excluded from processing.
Exclude bool `yaml:"exclude,omitempty"`
}
Header represents the header section of an alias file.
type Variables ¶
Variables represents a set of key-value pairs.
Click to show internal directories.
Click to hide internal directories.